pub struct BranchSubscriptionDiff {
pub max_diff_lines: Option<MaxDiffLines>,
pub notification_level: Option<NotificationLevel>,
pub review_level: Option<CodeReviewLevel>,
}Expand description
Representation of the branch_subscription-diff resource
Fields
max_diff_lines: Option<MaxDiffLines>Generated Diff Size Limit
Diffs greater than the specified number of lines will not be sent to the subscriber. The subscriber will still receive an email with the new revision details even if the diff is larger than the specified number of lines.
notification_level: Option<NotificationLevel>Notification Level
Attribute notifications are sent when branch details are changed such as lifecycle status and name. Revision notifications are generated when new branch revisions are found due to the branch being updated through either pushes to the hosted branches or the mirrored branches being updated.
review_level: Option<CodeReviewLevel>Code review Level
Control the kind of review activity that triggers notifications.