pub struct BugSubscriptionFilterFull {
pub self_link: Option<Url>,
pub web_link: Option<Url>,
pub resource_type_link: Option<Url>,
pub http_etag: Option<String>,
pub bug_notification_level: Level,
pub description: String,
pub find_all_tags: bool,
pub importances: Vec<String>,
pub information_types: Vec<String>,
pub statuses: Vec<String>,
pub structural_subscription_link: Url,
pub tags: String,
}Expand description
Representation of the bug_subscription_filter-full resource
Fields
self_link: Option<Url>The canonical link to this resource.
web_link: Option<Url>The canonical human-addressable web link to this resource.
resource_type_link: Option<Url>The link to the WADL description of this resource.
http_etag: Option<String>The value of the HTTP ETag for this resource.
bug_notification_level: LevelBug notification level
The volume and type of bug notifications this subscription will generate.
description: StringA short description of this filter
Find all tags
If enabled, all tags must match, else at least one tag must match.
importances: Vec<String>The importances interested in (empty for all)
information_types: Vec<String>The information types interested in (empty for all)
statuses: Vec<String>The statuses interested in (empty for all)
structural_subscription_link: UrlStructural subscription
The tags interested in
Implementations
Sourceimpl BugSubscriptionFilterFull
impl BugSubscriptionFilterFull
Sourcepub fn self_(&self) -> Option<BugSubscriptionFilter>
pub fn self_(&self) -> Option<BugSubscriptionFilter>
The canonical link to this resource.
Sourcepub fn set_self_(&mut self, value: Option<BugSubscriptionFilter>)
pub fn set_self_(&mut self, value: Option<BugSubscriptionFilter>)
Set the self_link value.
Sourcepub fn structural_subscription(&self) -> StructuralSubscription
pub fn structural_subscription(&self) -> StructuralSubscription
Structural subscription
Sourcepub fn set_structural_subscription(&mut self, value: StructuralSubscription)
pub fn set_structural_subscription(&mut self, value: StructuralSubscription)
Set the structural_subscription_link value.