pub struct BugTrackerComponentFull {
pub self_link: Option<Url>,
pub web_link: Option<Url>,
pub resource_type_link: Option<Url>,
pub http_etag: Option<String>,
pub component_group_link: Url,
pub distro_source_package_link: Url,
pub is_visible: bool,
pub name: String,
}Expand description
Representation of the bug_tracker_component-full resource
Fields
self_link: Option<Url>The canonical link to this resource.
web_link: Option<Url>The canonical human-addressable web link to this resource.
resource_type_link: Option<Url>The link to the WADL description of this resource.
http_etag: Option<String>The value of the HTTP ETag for this resource.
component_group_link: UrlComponent Group
distro_source_package_link: UrlDistribution Source Package
The distribution source package object that should be linked to this component.
is_visible: boolIs Visible?
Should the component be shown in the Launchpad web interface?
name: StringName
The name of a software component as shown in Launchpad.
Implementations
Sourceimpl BugTrackerComponentFull
impl BugTrackerComponentFull
Sourcepub fn self_(&self) -> Option<BugTrackerComponent>
pub fn self_(&self) -> Option<BugTrackerComponent>
The canonical link to this resource.
Sourcepub fn set_self_(&mut self, value: Option<BugTrackerComponent>)
pub fn set_self_(&mut self, value: Option<BugTrackerComponent>)
Set the self_link value.
Sourcepub fn component_group(&self) -> BugTrackerComponentGroup
pub fn component_group(&self) -> BugTrackerComponentGroup
Component Group
Sourcepub fn set_component_group(&mut self, value: BugTrackerComponentGroup)
pub fn set_component_group(&mut self, value: BugTrackerComponentGroup)
Set the component_group_link value.
Sourcepub fn distro_source_package(&self) -> DistributionSourcePackage
pub fn distro_source_package(&self) -> DistributionSourcePackage
Distribution Source Package
The distribution source package object that should be linked to this component.
Sourcepub fn set_distro_source_package(&mut self, value: DistributionSourcePackage)
pub fn set_distro_source_package(&mut self, value: DistributionSourcePackage)
Set the distro_source_package_link value.