pub struct DistroArchSeriesFull {Show 17 fields
pub self_link: Option<Url>,
pub web_link: Option<Url>,
pub resource_type_link: Option<Url>,
pub http_etag: Option<String>,
pub architecture_tag: String,
pub chroot_url: Url,
pub display_name: String,
pub distroseries_link: Url,
pub is_nominated_arch_indep: bool,
pub main_archive_link: Url,
pub official: bool,
pub owner_link: Url,
pub package_count: usize,
pub processor_link: Url,
pub supports_virtualized: bool,
pub title: String,
pub underlying_architecture_tag: String,
}Expand description
Representation of the distro_arch_series-full resource
Fields
self_link: Option<Url>The canonical link to this resource.
web_link: Option<Url>The canonical human-addressable web link to this resource.
resource_type_link: Option<Url>The link to the WADL description of this resource.
http_etag: Option<String>The value of the HTTP ETag for this resource.
architecture_tag: StringArchitecture Tag
The architecture tag, or short piece of text that identifies this architecture. All binary packages in the archive will use this tag in their filename. Please get it correct. It should really never be changed!
chroot_url: UrlBuild chroot URL
The URL to the current build chroot for this distroarchseries.
display_name: StringDisplay name
The display name of this distroarchseries.
distroseries_link: UrlThe context distroseries
is_nominated_arch_indep: boolIs Nominated Arch Independent
True if this distroarchseries is the NominatedArchIndep one.
main_archive_link: UrlMain Archive
The main archive of the distroarchseries.
official: boolOfficial Support
Indicate whether or not this port has official support from the vendor of the distribution.
owner_link: UrlThe person who registered this port.
package_count: usizePackage Count
A cache of the number of packages published in the RELEASE pocket of this port.
processor_link: UrlProcessor
supports_virtualized: boolPPA support available
Indicate whether or not this port has support for building PPA packages.
title: StringTitle
The title of this distroarchseries.
underlying_architecture_tag: StringUnderlying Architecture Tag
If set, identifies architecture_tag as a ‘variant’ of the specified architecture.
Implementations
Sourceimpl DistroArchSeriesFull
impl DistroArchSeriesFull
Sourcepub fn self_(&self) -> Option<DistroArchSeries>
pub fn self_(&self) -> Option<DistroArchSeries>
The canonical link to this resource.
Sourcepub fn set_self_(&mut self, value: Option<DistroArchSeries>)
pub fn set_self_(&mut self, value: Option<DistroArchSeries>)
Set the self_link value.
Sourcepub fn distroseries(&self) -> DistroSeries
pub fn distroseries(&self) -> DistroSeries
The context distroseries
Sourcepub fn set_distroseries(&mut self, value: DistroSeries)
pub fn set_distroseries(&mut self, value: DistroSeries)
Set the distroseries_link value.
Sourcepub fn main_archive(&self) -> Archive
pub fn main_archive(&self) -> Archive
Main Archive
The main archive of the distroarchseries.
Sourcepub fn set_main_archive(&mut self, value: Archive)
pub fn set_main_archive(&mut self, value: Archive)
Set the main_archive_link value.
Sourcepub fn set_processor(&mut self, value: Processor)
pub fn set_processor(&mut self, value: Processor)
Set the processor_link value.