DistroSeriesDiff

Struct DistroSeriesDiff 

pub struct DistroSeriesDiff {
Show 29 fields pub active: Option<bool>, pub advertise_by_hash: Option<bool>, pub backports_not_automatic: Option<bool>, pub bug_reported_acknowledgement: Option<String>, pub bug_reporting_guidelines: Option<String>, pub changeslist: Option<String>, pub content_templates: Option<String>, pub date_created: Option<DateTime<Utc>>, pub datereleased: Option<DateTime<Utc>>, pub description: Option<String>, pub displayname: Option<String>, pub distribution_link: Option<Url>, pub driver_link: Option<Url>, pub fullseriesname: Option<String>, pub include_long_descriptions: Option<bool>, pub index_compressors: Option<Vec<String>>, pub language_pack_full_export_requested: Option<bool>, pub main_archive_link: Option<Url>, pub name: Option<String>, pub nominatedarchindep_link: Option<Url>, pub proposed_not_automatic: Option<String>, pub publish_by_hash: Option<String>, pub publish_i18n_index: Option<String>, pub registrant_link: Option<Url>, pub status: Option<Status>, pub summary: Option<String>, pub supported: Option<bool>, pub title: Option<String>, pub version: Option<Version>,
}
Representation of the distro_series-diff resource

Fields

active: Option<bool>

Active

Whether or not this series is stable and supported, or under current development. This excludes series which are experimental or obsolete.

advertise_by_hash: Option<bool>

Advertise by-hash directories

Advertise by-hash directories with a flag in the Release file so that apt uses them by default. Only effective if publish_by_hash is also set.

backports_not_automatic: Option<bool>

Don’t upgrade to backports automatically

Set NotAutomatic: yes and ButAutomaticUpgrades: yes in Release files generated for the backports pocket. This tells apt to automatically upgrade within backports, but not into it.

bug_reported_acknowledgement: Option<String>

After reporting a bug, I can expect the following.

This message of acknowledgement will be displayed to anyone after reporting a bug.

bug_reporting_guidelines: Option<String>

Helpful guidelines for reporting a bug

These guidelines will be shown to everyone reporting a bug and should be text or a bulleted list with your particular requirements, if any.

changeslist: Option<String>

Email changes to

The mailing list or other email address that Launchpad should notify about new uploads.

content_templates: Option<String>

Templates to use for reporting a bug

This pre-defined template will be given to the users to guide them when reporting a bug.

date_created: Option<DateTime<Utc>>

The date this series was registered.

datereleased: Option<DateTime<Utc>>

Date released

description: Option<String>

Description

A detailed description of this series, with information on the architectures covered, the availability of security updates and any other relevant information.

displayname: Option<String>

Display name

The series displayname.

distribution_link: Option<Url>

Distribution

The distribution for which this is a series.

driver_link: Option<Url>

Driver

The person or team responsible for decisions about features and bugs that will be targeted to this series of the distribution.

fullseriesname: Option<String>

Series full name

The series full name, e.g. Ubuntu Warty

include_long_descriptions: Option<bool>

Include long descriptions in Packages rather than in Translation-en

If True, write long descriptions to the per-architecture Packages files; if False, write them to a Translation-en file common across architectures instead. Using a common file reduces the bandwidth footprint of enabling multiarch on clients, which requires downloading Packages files for multiple architectures.

index_compressors: Option<Vec<String>>

Compression types to use for published index files

A list of compression types to use for published index files (Packages, Sources, etc.).

language_pack_full_export_requested: Option<bool>

Request a full language pack export

Whether next language pack generation will be a full export. This information is useful when update packs are too big and want to merge all those changes in the base pack.

main_archive_link: Option<Url>

Distribution Main Archive

name: Option<String>

Name

The name of this series.

nominatedarchindep_link: Option<Url>

DistroArchSeries designed to build architecture-independent packages within this distroseries context.

proposed_not_automatic: Option<String>

Don’t upgrade to proposed updates automatically

Set NotAutomatic: yes and ButAutomaticUpgrades: yes in Release files generated for the proposed pocket. This tells apt to automatically upgrade within proposed, but not into it.

publish_by_hash: Option<String>

Publish by-hash directories

Publish archive index files in by-hash directories so that apt can retrieve them based on their hash, avoiding race conditions between InRelease and other files during mirror updates.

publish_i18n_index: Option<String>

Publish I18n index

Publish archive i18n/Index file, which is believed to be unused.

registrant_link: Option<Url>

Registrant

status: Option<Status>

Status

summary: Option<String>

Summary

A single paragraph that explains the goals of of this series and the intended users. For example: “The 2.0 series of Apache represents the current stable series, and is recommended for all new deployments”.

supported: Option<bool>

Supported

Whether or not this series is currently supported.

title: Option<String>

Title

The title of this series. It should be distinctive and designed to look good at the top of a page.

version: Option<Version>

Version

The version string for this series.

Implementations

Source

impl DistroSeriesDiff

pub fn distribution(&self) -> Option<Distribution>

Distribution

The distribution for which this is a series.

pub fn set_distribution(&mut self, value: Option<Distribution>)

Set the distribution_link value.

pub fn driver(&self) -> Option<Person>

Driver

The person or team responsible for decisions about features and bugs that will be targeted to this series of the distribution.

pub fn set_driver(&mut self, value: Option<Person>)

Set the driver_link value.

pub fn main_archive(&self) -> Option<Archive>

Distribution Main Archive

pub fn set_main_archive(&mut self, value: Option<Archive>)

Set the main_archive_link value.

pub fn nominatedarchindep(&self) -> Option<DistroArchSeries>

DistroArchSeries designed to build architecture-independent packages within this distroseries context.

pub fn set_nominatedarchindep(&mut self, value: Option<DistroArchSeries>)

Set the nominatedarchindep_link value.

pub fn registrant(&self) -> Option<Person>

Registrant

pub fn set_registrant(&mut self, value: Option<Person>)

Set the registrant_link value.