pub struct RockBaseFull {
pub self_link: Option<Url>,
pub web_link: Option<Url>,
pub resource_type_link: Option<Url>,
pub http_etag: Option<String>,
pub build_channels: Vec<String>,
pub date_created: DateTime<Utc>,
pub distro_series_link: Url,
pub processors_collection_link: Url,
pub registrant_link: Url,
}Expand description
Representation of the rock_base-full resource
Fields
self_link: Option<Url>The canonical link to this resource.
web_link: Option<Url>The canonical human-addressable web link to this resource.
resource_type_link: Option<Url>The link to the WADL description of this resource.
http_etag: Option<String>The value of the HTTP ETag for this resource.
build_channels: Vec<String>Source snap channels for builds
A dictionary mapping snap names to channels to use when building rock recipes that specify this base. The special ‘_byarch’ key may have a mapping of architecture names to mappings of snap names to channels, which if present override the channels declared at the top level when building for those architectures.
date_created: DateTime<Utc>Date created
distro_series_link: UrlDistro series
processors_collection_link: UrlProcessors
The architectures that the rock base supports.
registrant_link: UrlRegistrant
The person who registered this base.
Implementations
Sourceimpl RockBaseFull
impl RockBaseFull
Sourcepub fn distro_series(&self) -> DistroSeries
pub fn distro_series(&self) -> DistroSeries
Distro series
Sourcepub fn set_distro_series(&mut self, value: DistroSeries)
pub fn set_distro_series(&mut self, value: DistroSeries)
Set the distro_series_link value.
Sourcepub fn processors<'a>(
&'a self,
client: &'a dyn Client,
) -> Result<PagedCollection<'a, ProcessorPage>, Error>
pub fn processors<'a>( &'a self, client: &'a dyn Client, ) -> Result<PagedCollection<'a, ProcessorPage>, Error>
Processors
The architectures that the rock base supports.
Sourcepub fn registrant(&self) -> Person
pub fn registrant(&self) -> Person
Registrant
The person who registered this base.
Sourcepub fn set_registrant(&mut self, value: Person)
pub fn set_registrant(&mut self, value: Person)
Set the registrant_link value.