SnapDiff

Struct SnapDiff 

pub struct SnapDiff {
Show 23 fields pub allow_internet: Option<bool>, pub auto_build: Option<bool>, pub auto_build_archive_link: Option<Url>, pub auto_build_channels: Option<Vec<String>>, pub auto_build_pocket: Option<Pocket>, pub branch_link: Option<Url>, pub build_source_tarball: Option<Url>, pub description: Option<String>, pub distro_series_link: Option<Url>, pub fetch_service_policy: Option<FetchServicePolicy>, pub git_path: Option<String>, pub git_ref_link: Option<Url>, pub information_type: Option<InformationType>, pub name: Option<String>, pub owner_link: Option<Url>, pub private: Option<bool>, pub pro_enable: Option<String>, pub require_virtualized: Option<bool>, pub store_channels: Option<Vec<String>>, pub store_name: Option<String>, pub store_series_link: Option<Url>, pub store_upload: Option<String>, pub use_fetch_service: Option<String>,
}
Representation of the snap-diff resource

Fields

allow_internet: Option<bool>

Allow external network access

Allow access to external network resources via a proxy. Resources hosted on Launchpad itself are always allowed.

auto_build: Option<bool>

Automatically build when branch changes

Whether this snap package is built automatically when the branch containing its snap/snapcraft.yaml, build-aux/snap/snapcraft.yaml, snapcraft.yaml, or .snapcraft.yaml recipe changes.

auto_build_archive_link: Option<Url>

Source archive for automatic builds

The archive from which automatic builds of this snap package should be built.

auto_build_channels: Option<Vec<String>>

Source snap channels for automatic builds

A dictionary mapping snap names to channels to use when building this snap package. Supported snap names: ‘core’, ‘core18’, ‘core20’, ‘core22’, ‘core24’, ‘core26’, ‘snapcraft’, ‘snapd’

auto_build_pocket: Option<Pocket>

Pocket for automatic builds

The package stream within the source archive and distribution series to use when building the snap package. If the source archive is a PPA, then the PPA’s archive dependencies will be used to select the pocket in the distribution’s primary archive.

branch_link: Option<Url>

Bazaar branch

A Bazaar branch containing a snap/snapcraft.yaml, build-aux/snap/snapcraft.yaml, snapcraft.yaml, or .snapcraft.yaml recipe at the top level.

build_source_tarball: Option<Url>

Build source tarball

Whether builds of this snap package should also build a tarball containing all source code, including external dependencies.

description: Option<String>

Description

A description of the snap package.

distro_series_link: Option<Url>

Distro Series

The series for which the snap package should be built. If not set, Launchpad will infer an appropriate series from snapcraft.yaml.

fetch_service_policy: Option<FetchServicePolicy>

Fetch service policy

Which policy to use when using the fetch service. The “strict” mode only allows certain resources and formats, and errors out in any case the restrictions are violated. The “permissive” mode works similarly, but only logs a warning when encountering any violations.

git_path: Option<String>

Git branch path

The path of the Git branch containing a snap/snapcraft.yaml, build-aux/snap/snapcraft.yaml, snapcraft.yaml, or .snapcraft.yaml recipe at the top level.

git_ref_link: Option<Url>

Git branch

The Git branch containing a snap/snapcraft.yaml, build-aux/snap/snapcraft.yaml, snapcraft.yaml, or .snapcraft.yaml recipe at the top level.

information_type: Option<InformationType>

Information type

The type of information contained in this Snap recipe.

name: Option<String>

Snap recipe name

The name of the snap build recipe.

owner_link: Option<Url>

Owner

The owner of this snap package.

private: Option<bool>

Private

Whether or not this snap is private.

pro_enable: Option<String>

Enable Ubuntu Pro

Allow building this snap recipe using dependencies from Ubuntu Pro, if configured for the corresponding snap base.

require_virtualized: Option<bool>

Require virtualized builders

Only build this snap package on virtual builders.

store_channels: Option<Vec<String>>

Store channels

Channels to release this snap package to after uploading it to the store. A channel is defined by a combination of an optional track, a risk, and an optional branch, e.g. ‘2.1/stable/fix-123’, ‘2.1/stable’, ‘stable/fix-123’, or ‘stable’.

store_name: Option<String>

Registered store package name

The registered name of this snap package in the store.

store_series_link: Option<Url>

Store series

The series in which this snap package should be published in the store.

store_upload: Option<String>

Automatically upload to store

Whether builds of this snap package are automatically uploaded to the store.

use_fetch_service: Option<String>

Use fetch service

If set, Snap builds will use the fetch-service instead of the builder-proxy to access external resources.

Implementations

Source

impl SnapDiff

pub fn auto_build_archive(&self) -> Option<Archive>

Source archive for automatic builds

The archive from which automatic builds of this snap package should be built.

pub fn set_auto_build_archive(&mut self, value: Option<Archive>)

Set the auto_build_archive_link value.

pub fn branch(&self) -> Option<Branch>

Bazaar branch

A Bazaar branch containing a snap/snapcraft.yaml, build-aux/snap/snapcraft.yaml, snapcraft.yaml, or .snapcraft.yaml recipe at the top level.

pub fn set_branch(&mut self, value: Option<Branch>)

Set the branch_link value.

pub fn distro_series(&self) -> Option<DistroSeries>

Distro Series

The series for which the snap package should be built. If not set, Launchpad will infer an appropriate series from snapcraft.yaml.

pub fn set_distro_series(&mut self, value: Option<DistroSeries>)

Set the distro_series_link value.

pub fn git_ref(&self) -> Option<GitRef>

Git branch

The Git branch containing a snap/snapcraft.yaml, build-aux/snap/snapcraft.yaml, snapcraft.yaml, or .snapcraft.yaml recipe at the top level.

pub fn set_git_ref(&mut self, value: Option<GitRef>)

Set the git_ref_link value.

pub fn owner(&self) -> Option<Person>

Owner

The owner of this snap package.

pub fn set_owner(&mut self, value: Option<Person>)

Set the owner_link value.

pub fn store_series(&self) -> Option<SnappySeries>

Store series

The series in which this snap package should be published in the store.

pub fn set_store_series(&mut self, value: Option<SnappySeries>)

Set the store_series_link value.