pub struct SourcePackagePublishingHistoryDiff {
pub date_created: Option<DateTime<Utc>>,
pub date_made_pending: Option<DateTime<Utc>>,
pub date_published: Option<DateTime<Utc>>,
pub date_removed: Option<DateTime<Utc>>,
pub date_superseded: Option<DateTime<Utc>>,
pub display_name: Option<String>,
pub distro_series_link: Option<Url>,
pub removal_comment: Option<String>,
pub removed_by_link: Option<Url>,
pub scheduled_deletion_date: Option<DateTime<Utc>>,
pub status: Option<PublishingRecordStatus>,
}Expand description
Representation of the source_package_publishing_history-diff resource
Fields
date_created: Option<DateTime<Utc>>The date on which this record was created
date_made_pending: Option<DateTime<Utc>>The date on which this record was set as pending removal
date_published: Option<DateTime<Utc>>The date on which this record was published
date_removed: Option<DateTime<Utc>>The date on which this record was removed from the published set
date_superseded: Option<DateTime<Utc>>The date on which this record was marked superseded
display_name: Option<String>Display Name
Text representation of the current record.
distro_series_link: Option<Url>The distro series being published into
removal_comment: Option<String>Reason why this publication is going to be removed.
removed_by_link: Option<Url>The IPerson responsible for the removal
scheduled_deletion_date: Option<DateTime<Utc>>The date on which this record is scheduled for deletion
status: Option<PublishingRecordStatus>Package Publishing Status
The status of this publishing record
Implementations
Sourceimpl SourcePackagePublishingHistoryDiff
impl SourcePackagePublishingHistoryDiff
Sourcepub fn distro_series(&self) -> Option<DistroSeries>
pub fn distro_series(&self) -> Option<DistroSeries>
The distro series being published into
Sourcepub fn set_distro_series(&mut self, value: Option<DistroSeries>)
pub fn set_distro_series(&mut self, value: Option<DistroSeries>)
Set the distro_series_link value.
Sourcepub fn removed_by(&self) -> Option<Person>
pub fn removed_by(&self) -> Option<Person>
The IPerson responsible for the removal
Sourcepub fn set_removed_by(&mut self, value: Option<Person>)
pub fn set_removed_by(&mut self, value: Option<Person>)
Set the removed_by_link value.