pub struct WebhookDelivery(/* private fields */);Expand description
A Job that delivers an event to a webhook consumer.
Implementations
Sourceimpl WebhookDelivery
impl WebhookDelivery
Sourcepub fn get<'a>(
&self,
client: &'a dyn Client,
) -> Result<WebhookDeliveryFull, Error>
pub fn get<'a>( &self, client: &'a dyn Client, ) -> Result<WebhookDeliveryFull, Error>
Retrieve the resource.
Returns
Returns WebhookDeliveryFull on success, or an error if the request fails.
Sourcepub fn get_wadl<'a>(&self, client: &'a dyn Client) -> Result<Resource, Error>
pub fn get_wadl<'a>(&self, client: &'a dyn Client) -> Result<Resource, Error>
Retrieve the WADL description for this resource.
This method fetches the WADL (Web Application Description Language) specification for the current resource, allowing for runtime API discovery.
Returns
Returns the wadl::ast::Resource definition on success, or an error if the request fails.