pub struct ArchivePermissionFull {Show 14 fields
pub self_link: Option<Url>,
pub resource_type_link: Option<Url>,
pub http_etag: Option<String>,
pub archive_link: Url,
pub component_name: String,
pub date_created: DateTime<Utc>,
pub distro_series_name: String,
pub distroseries_link: Url,
pub explicit: bool,
pub package_set_name: String,
pub permission: String,
pub person_link: Url,
pub pocket: Pocket,
pub source_package_name: String,
}Expand description
Representation of the archive_permission-full resource
Fields
self_link: Option<Url>The canonical link to this resource.
resource_type_link: Option<Url>The link to the WADL description of this resource.
http_etag: Option<String>The value of the HTTP ETag for this resource.
archive_link: UrlArchive
The archive that this permission is for.
component_name: StringComponent Name
date_created: DateTime<Utc>Date Created
The timestamp when the permission was created.
distro_series_name: StringThe name of the distro series associated with the package set.
distroseries_link: UrlDistro series
The distro series that this permission is for (only for pocket permissions).
explicit: boolExplicit
Set this flag for package sets with high-profile packages requiring specialist skills for proper handling.
package_set_name: StringPackage set name
permission: StringThe permission type being granted.
person_link: UrlPerson
The person or team being granted the permission.
pocket: PocketThe pocket that this permission is for.
source_package_name: StringSource Package Name
Implementations
Sourceimpl ArchivePermissionFull
impl ArchivePermissionFull
Sourcepub fn self_(&self) -> Option<ArchivePermission>
pub fn self_(&self) -> Option<ArchivePermission>
The canonical link to this resource.
Sourcepub fn set_self_(&mut self, value: Option<ArchivePermission>)
pub fn set_self_(&mut self, value: Option<ArchivePermission>)
Set the self_link value.
Sourcepub fn set_archive(&mut self, value: Archive)
pub fn set_archive(&mut self, value: Archive)
Set the archive_link value.
Sourcepub fn distroseries(&self) -> DistroSeries
pub fn distroseries(&self) -> DistroSeries
Distro series
The distro series that this permission is for (only for pocket permissions).
Sourcepub fn set_distroseries(&mut self, value: DistroSeries)
pub fn set_distroseries(&mut self, value: DistroSeries)
Set the distroseries_link value.
Sourcepub fn set_person(&mut self, value: Person)
pub fn set_person(&mut self, value: Person)
Set the person_link value.