pub struct BranchSubscriptionFull {
pub self_link: Option<Url>,
pub web_link: Option<Url>,
pub resource_type_link: Option<Url>,
pub http_etag: Option<String>,
pub branch_link: Url,
pub max_diff_lines: MaxDiffLines,
pub notification_level: NotificationLevel,
pub person_link: Url,
pub review_level: CodeReviewLevel,
pub subscribed_by_link: Url,
}Expand description
Representation of the branch_subscription-full resource
Fields
self_link: Option<Url>The canonical link to this resource.
web_link: Option<Url>The canonical human-addressable web link to this resource.
resource_type_link: Option<Url>The link to the WADL description of this resource.
http_etag: Option<String>The value of the HTTP ETag for this resource.
branch_link: UrlBranch ID
max_diff_lines: MaxDiffLinesGenerated Diff Size Limit
Diffs greater than the specified number of lines will not be sent to the subscriber. The subscriber will still receive an email with the new revision details even if the diff is larger than the specified number of lines.
notification_level: NotificationLevelNotification Level
Attribute notifications are sent when branch details are changed such as lifecycle status and name. Revision notifications are generated when new branch revisions are found due to the branch being updated through either pushes to the hosted branches or the mirrored branches being updated.
person_link: UrlPerson
Enter the launchpad id, or email address of the person you wish to subscribe to this branch. If you are unsure, use the “Choose…” option to find the person in Launchpad. You can only subscribe someone who is a registered user of the system.
review_level: CodeReviewLevelCode review Level
Control the kind of review activity that triggers notifications.
subscribed_by_link: UrlSubscribed by
The person who created this subscription.
Implementations
Sourceimpl BranchSubscriptionFull
impl BranchSubscriptionFull
Sourcepub fn self_(&self) -> Option<BranchSubscription>
pub fn self_(&self) -> Option<BranchSubscription>
The canonical link to this resource.
Sourcepub fn set_self_(&mut self, value: Option<BranchSubscription>)
pub fn set_self_(&mut self, value: Option<BranchSubscription>)
Set the self_link value.
Sourcepub fn set_branch(&mut self, value: Branch)
pub fn set_branch(&mut self, value: Branch)
Set the branch_link value.
Sourcepub fn person(&self) -> Person
pub fn person(&self) -> Person
Person
Enter the launchpad id, or email address of the person you wish to subscribe to this branch. If you are unsure, use the “Choose…” option to find the person in Launchpad. You can only subscribe someone who is a registered user of the system.
Sourcepub fn set_person(&mut self, value: Person)
pub fn set_person(&mut self, value: Person)
Set the person_link value.
Sourcepub fn subscribed_by(&self) -> Person
pub fn subscribed_by(&self) -> Person
Subscribed by
The person who created this subscription.
Sourcepub fn set_subscribed_by(&mut self, value: Person)
pub fn set_subscribed_by(&mut self, value: Person)
Set the subscribed_by_link value.