pub struct BugDiff {
pub description: Option<String>,
pub duplicate_of_link: Option<Url>,
pub name: Option<String>,
pub private: Option<bool>,
pub security_related: Option<bool>,
pub tags: Option<String>,
pub title: Option<String>,
}Expand description
Representation of the bug-diff resource
Fields
description: Option<String>Description
A detailed description of the problem, including the steps required to reproduce it.
duplicate_of_link: Option<Url>Duplicate Of
name: Option<String>Nickname
A short and unique name. Add one only if you often need to retype the URL but have trouble remembering the bug number.
private: Option<bool>This bug report should be private
Private bug reports are visible only to their subscribers.
This bug is a security vulnerability.
Tags
Space-separated keywords for classifying this bug report.
title: Option<String>Summary
A one-line summary of the problem.
Implementations