pub struct BugTrackerFull {Show 15 fields
pub self_link: Option<Url>,
pub web_link: Option<Url>,
pub resource_type_link: Option<Url>,
pub http_etag: Option<String>,
pub active: bool,
pub base_url: Url,
pub base_url_aliases: Vec<Url>,
pub bug_tracker_type: BugTrackerType,
pub contact_details: String,
pub has_lp_plugin: bool,
pub name: String,
pub registrant_link: Url,
pub summary: String,
pub title: String,
pub watches_collection_link: Url,
}Expand description
Representation of the bug_tracker-full resource
Fields
self_link: Option<Url>The canonical link to this resource.
web_link: Option<Url>The canonical human-addressable web link to this resource.
resource_type_link: Option<Url>The link to the WADL description of this resource.
http_etag: Option<String>The value of the HTTP ETag for this resource.
active: boolUpdates for this bug tracker are enabled
base_url: UrlLocation
The top-level URL for the bug tracker, or an upstream email address. This must be accurate so that Launchpad can link to external bug reports.
base_url_aliases: Vec<Url>Location aliases
A list of URLs or email addresses that all lead to the same bug tracker, or commonly seen typos, separated by whitespace.
bug_tracker_type: BugTrackerTypeBug Tracker Type
contact_details: StringContact details
The contact details for the external bug tracker (so that, for example, its administrators can be contacted about a security breach).
has_lp_plugin: boolThis bug tracker has a Launchpad plugin installed.
name: StringName
A URL-friendly name for the bug tracker, such as “mozilla-bugs”.
registrant_link: UrlOwner
summary: StringSummary
A brief introduction or overview of this bug tracker instance.
title: StringTitle
A descriptive label for this tracker to show in listings.
watches_collection_link: UrlThe remote watches on this bug tracker.
Implementations
Sourceimpl BugTrackerFull
impl BugTrackerFull
Sourcepub fn self_(&self) -> Option<BugTracker>
pub fn self_(&self) -> Option<BugTracker>
The canonical link to this resource.
Sourcepub fn set_self_(&mut self, value: Option<BugTracker>)
pub fn set_self_(&mut self, value: Option<BugTracker>)
Set the self_link value.
Sourcepub fn registrant(&self) -> Person
pub fn registrant(&self) -> Person
Owner
Sourcepub fn set_registrant(&mut self, value: Person)
pub fn set_registrant(&mut self, value: Person)
Set the registrant_link value.
Sourcepub fn watches<'a>(
&'a self,
client: &'a dyn Client,
) -> Result<PagedCollection<'a, BugWatchPage>, Error>
pub fn watches<'a>( &'a self, client: &'a dyn Client, ) -> Result<PagedCollection<'a, BugWatchPage>, Error>
The remote watches on this bug tracker.