pub struct CraftRecipeDiff {Show 16 fields
pub auto_build: Option<bool>,
pub auto_build_channels: Option<Vec<String>>,
pub build_path: Option<String>,
pub description: Option<String>,
pub fetch_service_policy: Option<FetchServicePolicy>,
pub git_ref_link: Option<Url>,
pub information_type: Option<InformationType>,
pub name: Option<String>,
pub owner_link: Option<Url>,
pub private: Option<bool>,
pub project_link: Option<Url>,
pub require_virtualized: Option<bool>,
pub store_channels: Option<Vec<String>>,
pub store_name: Option<String>,
pub store_upload: Option<String>,
pub use_fetch_service: Option<String>,
}Expand description
Representation of the craft_recipe-diff resource
Fields
auto_build: Option<bool>Automatically build when branch changes
Whether this craft recipe is built automatically when the branch containing its craft.yaml recipe changes.
auto_build_channels: Option<Vec<String>>Source snap channels for automatic builds
A dictionary mapping snap names to channels to use when building this craft recipe. Currently only ‘core’, ‘core18’, ‘core20’, and ‘sourcecraft’ keys are supported.
build_path: Option<String>Build path
Subdirectory within the branch containing craft.yaml.
description: Option<String>Description
A description of the craft recipe.
fetch_service_policy: Option<FetchServicePolicy>Fetch service policy
Which policy to use when using the fetch service. Ignored if use_fetch_service flag is False.
git_ref_link: Option<Url>Git branch
The Git branch containing a craft.yaml recipe.
information_type: Option<InformationType>Information type
The type of information contained in this craft recipe.
name: Option<String>Craft recipe name
The name of the craft recipe.
owner_link: Option<Url>Owner
The owner of this craft recipe.
private: Option<bool>Private
Whether this craft recipe is private.
project_link: Option<Url>The project that this craft recipe is associated with
require_virtualized: Option<bool>Require virtualized builders
Only build this craft recipe on virtual builders.
store_channels: Option<Vec<String>>Store channels
Channels to release this craft to after uploading it to the store. A channel is defined by a combination of an optional track, a risk, and an optional branch, e.g. ‘2.1/stable/fix-123’, ‘2.1/stable’, ‘stable/fix-123’, or ‘stable’.
store_name: Option<String>Registered store name
The registered name of this craft in the store.
store_upload: Option<String>Automatically upload to store
Whether builds of this craft recipe are automatically uploaded to the store.
use_fetch_service: Option<String>Use fetch service
If set, Craft builds will use the fetch-service instead of the builder-proxy to access external resources.
Implementations
Sourceimpl CraftRecipeDiff
impl CraftRecipeDiff