DistroArchSeriesDiff

Struct DistroArchSeriesDiff 

pub struct DistroArchSeriesDiff {
    pub architecture_tag: Option<String>,
    pub display_name: Option<String>,
    pub distroseries_link: Option<Url>,
    pub is_nominated_arch_indep: Option<bool>,
    pub main_archive_link: Option<Url>,
    pub official: Option<bool>,
    pub owner_link: Option<Url>,
    pub package_count: Option<usize>,
    pub title: Option<String>,
    pub underlying_architecture_tag: Option<String>,
}
Representation of the distro_arch_series-diff resource

Fields

architecture_tag: Option<String>

Architecture Tag

The architecture tag, or short piece of text that identifies this architecture. All binary packages in the archive will use this tag in their filename. Please get it correct. It should really never be changed!

display_name: Option<String>

Display name

The display name of this distroarchseries.

distroseries_link: Option<Url>

The context distroseries

is_nominated_arch_indep: Option<bool>

Is Nominated Arch Independent

True if this distroarchseries is the NominatedArchIndep one.

main_archive_link: Option<Url>

Main Archive

The main archive of the distroarchseries.

official: Option<bool>

Official Support

Indicate whether or not this port has official support from the vendor of the distribution.

owner_link: Option<Url>

The person who registered this port.

package_count: Option<usize>

Package Count

A cache of the number of packages published in the RELEASE pocket of this port.

title: Option<String>

Title

The title of this distroarchseries.

underlying_architecture_tag: Option<String>

Underlying Architecture Tag

If set, identifies architecture_tag as a ‘variant’ of the specified architecture.

Implementations

Source

impl DistroArchSeriesDiff

pub fn distroseries(&self) -> Option<DistroSeries>

The context distroseries

pub fn set_distroseries(&mut self, value: Option<DistroSeries>)

Set the distroseries_link value.

pub fn main_archive(&self) -> Option<Archive>

Main Archive

The main archive of the distroarchseries.

pub fn set_main_archive(&mut self, value: Option<Archive>)

Set the main_archive_link value.

pub fn owner(&self) -> Option<Person>

The person who registered this port.

pub fn set_owner(&mut self, value: Option<Person>)

Set the owner_link value.