ServiceRootJson

Struct ServiceRootJson 

pub struct ServiceRootJson {
Show 34 fields pub archives_collection_link: Option<Url>, pub branches_collection_link: Option<Url>, pub bug_trackers_collection_link: Option<Url>, pub bugs_collection_link: Option<Url>, pub builders_collection_link: Option<Url>, pub charm_bases_collection_link: Option<Url>, pub charm_recipes_collection_link: Option<Url>, pub countries_collection_link: Option<Url>, pub craft_recipes_collection_link: Option<Url>, pub cves_collection_link: Option<Url>, pub distributions_collection_link: Option<Url>, pub git_repositories_collection_link: Option<Url>, pub languages_collection_link: Option<Url>, pub livefses_collection_link: Option<Url>, pub me_link: Option<Url>, pub packagesets_collection_link: Option<Url>, pub people_collection_link: Option<Url>, pub pillars_link: Option<Url>, pub polls_collection_link: Option<Url>, pub processors_collection_link: Option<Url>, pub project_groups_collection_link: Option<Url>, pub projects_collection_link: Option<Url>, pub questions_collection_link: Option<Url>, pub rock_bases_collection_link: Option<Url>, pub rock_recipes_collection_link: Option<Url>, pub services_link: Option<Url>, pub snap_bases_collection_link: Option<Url>, pub snappy_serieses_collection_link: Option<Url>, pub snaps_collection_link: Option<Url>, pub specifications_collection_link: Option<Url>, pub temporary_blobs_collection_link: Option<Url>, pub translation_groups_collection_link: Option<Url>, pub translation_import_queue_entries_collection_link: Option<Url>, pub resource_type_link: Option<Url>,
}
About this service

The Launchpad web service allows automated clients to access most of the functionality available on the Launchpad web site. For help getting started, see the help wiki.

About version 1.0

This version of the web service removes unnecessary named operations. It was introduced in March 2010, and its end-of-life date is April 2015, the same as the server version of the Ubuntu release “Lucid Lynx”. Representation of the service-root-json resource

Fields

archives_collection_link: Option<Url>branches_collection_link: Option<Url>bug_trackers_collection_link: Option<Url>bugs_collection_link: Option<Url>builders_collection_link: Option<Url>charm_bases_collection_link: Option<Url>charm_recipes_collection_link: Option<Url>countries_collection_link: Option<Url>craft_recipes_collection_link: Option<Url>cves_collection_link: Option<Url>distributions_collection_link: Option<Url>git_repositories_collection_link: Option<Url>languages_collection_link: Option<Url>livefses_collection_link: Option<Url>me_link: Option<Url>packagesets_collection_link: Option<Url>people_collection_link: Option<Url>pillars_link: Option<Url>polls_collection_link: Option<Url>processors_collection_link: Option<Url>project_groups_collection_link: Option<Url>projects_collection_link: Option<Url>questions_collection_link: Option<Url>rock_bases_collection_link: Option<Url>rock_recipes_collection_link: Option<Url>services_link: Option<Url>snap_bases_collection_link: Option<Url>snappy_serieses_collection_link: Option<Url>snaps_collection_link: Option<Url>specifications_collection_link: Option<Url>temporary_blobs_collection_link: Option<Url>translation_groups_collection_link: Option<Url>translation_import_queue_entries_collection_link: Option<Url>resource_type_link: Option<Url>

The link to the WADL description of this resource.

Implementations

Source

impl ServiceRootJson

pub fn archives(&self) -> Option<Archives>

Get the archives_collection_link value.

pub fn set_archives(&mut self, value: Option<Archives>)

Set the archives_collection_link value.

pub fn branches(&self) -> Option<Branches>

Get the branches_collection_link value.

pub fn set_branches(&mut self, value: Option<Branches>)

Set the branches_collection_link value.

pub fn bug_trackers(&self) -> Option<BugTrackers>

Get the bug_trackers_collection_link value.

pub fn set_bug_trackers(&mut self, value: Option<BugTrackers>)

Set the bug_trackers_collection_link value.

pub fn bugs(&self) -> Option<Bugs>

Get the bugs_collection_link value.

pub fn set_bugs(&mut self, value: Option<Bugs>)

Set the bugs_collection_link value.

pub fn builders(&self) -> Option<Builders>

Get the builders_collection_link value.

pub fn set_builders(&mut self, value: Option<Builders>)

Set the builders_collection_link value.

pub fn charm_bases(&self) -> Option<CharmBases>

Get the charm_bases_collection_link value.

pub fn set_charm_bases(&mut self, value: Option<CharmBases>)

Set the charm_bases_collection_link value.

pub fn charm_recipes(&self) -> Option<CharmRecipes>

Get the charm_recipes_collection_link value.

pub fn set_charm_recipes(&mut self, value: Option<CharmRecipes>)

Set the charm_recipes_collection_link value.

pub fn countries(&self) -> Option<Countries>

Get the countries_collection_link value.

pub fn set_countries(&mut self, value: Option<Countries>)

Set the countries_collection_link value.

pub fn craft_recipes(&self) -> Option<CraftRecipes>

Get the craft_recipes_collection_link value.

pub fn set_craft_recipes(&mut self, value: Option<CraftRecipes>)

Set the craft_recipes_collection_link value.

pub fn cves(&self) -> Option<Cves>

Get the cves_collection_link value.

pub fn set_cves(&mut self, value: Option<Cves>)

Set the cves_collection_link value.

pub fn distributions(&self) -> Option<Distributions>

Get the distributions_collection_link value.

pub fn set_distributions(&mut self, value: Option<Distributions>)

Set the distributions_collection_link value.

pub fn git_repositories(&self) -> Option<GitRepositories>

Get the git_repositories_collection_link value.

pub fn set_git_repositories(&mut self, value: Option<GitRepositories>)

Set the git_repositories_collection_link value.

pub fn languages(&self) -> Option<Languages>

Get the languages_collection_link value.

pub fn set_languages(&mut self, value: Option<Languages>)

Set the languages_collection_link value.

pub fn livefses(&self) -> Option<Livefses>

Get the livefses_collection_link value.

pub fn set_livefses(&mut self, value: Option<Livefses>)

Set the livefses_collection_link value.

pub fn me(&self) -> Option<Person>

Get the me_link value.

pub fn set_me(&mut self, value: Option<Person>)

Set the me_link value.

pub fn packagesets(&self) -> Option<Packagesets>

Get the packagesets_collection_link value.

pub fn set_packagesets(&mut self, value: Option<Packagesets>)

Set the packagesets_collection_link value.

pub fn people(&self) -> Option<People>

Get the people_collection_link value.

pub fn set_people(&mut self, value: Option<People>)

Set the people_collection_link value.

pub fn pillars(&self) -> Option<Pillars>

Get the pillars_link value.

pub fn set_pillars(&mut self, value: Option<Pillars>)

Set the pillars_link value.

pub fn polls(&self) -> Option<Polls>

Get the polls_collection_link value.

pub fn set_polls(&mut self, value: Option<Polls>)

Set the polls_collection_link value.

pub fn processors(&self) -> Option<Processors>

Get the processors_collection_link value.

pub fn set_processors(&mut self, value: Option<Processors>)

Set the processors_collection_link value.

pub fn project_groups(&self) -> Option<ProjectGroups>

Get the project_groups_collection_link value.

pub fn set_project_groups(&mut self, value: Option<ProjectGroups>)

Set the project_groups_collection_link value.

pub fn projects(&self) -> Option<Projects>

Get the projects_collection_link value.

pub fn set_projects(&mut self, value: Option<Projects>)

Set the projects_collection_link value.

pub fn questions(&self) -> Option<Questions>

Get the questions_collection_link value.

pub fn set_questions(&mut self, value: Option<Questions>)

Set the questions_collection_link value.

pub fn rock_bases(&self) -> Option<RockBases>

Get the rock_bases_collection_link value.

pub fn set_rock_bases(&mut self, value: Option<RockBases>)

Set the rock_bases_collection_link value.

pub fn rock_recipes(&self) -> Option<RockRecipes>

Get the rock_recipes_collection_link value.

pub fn set_rock_recipes(&mut self, value: Option<RockRecipes>)

Set the rock_recipes_collection_link value.

pub fn services(&self) -> Option<ServiceFactory>

Get the services_link value.

pub fn set_services(&mut self, value: Option<ServiceFactory>)

Set the services_link value.

pub fn snap_bases(&self) -> Option<SnapBases>

Get the snap_bases_collection_link value.

pub fn set_snap_bases(&mut self, value: Option<SnapBases>)

Set the snap_bases_collection_link value.

pub fn snappy_serieses(&self) -> Option<SnappySerieses>

Get the snappy_serieses_collection_link value.

pub fn set_snappy_serieses(&mut self, value: Option<SnappySerieses>)

Set the snappy_serieses_collection_link value.

pub fn snaps(&self) -> Option<Snaps>

Get the snaps_collection_link value.

pub fn set_snaps(&mut self, value: Option<Snaps>)

Set the snaps_collection_link value.

pub fn specifications(&self) -> Option<Specifications>

Get the specifications_collection_link value.

pub fn set_specifications(&mut self, value: Option<Specifications>)

Set the specifications_collection_link value.

pub fn temporary_blobs(&self) -> Option<TemporaryBlobs>

Get the temporary_blobs_collection_link value.

pub fn set_temporary_blobs(&mut self, value: Option<TemporaryBlobs>)

Set the temporary_blobs_collection_link value.

pub fn translation_groups(&self) -> Option<TranslationGroups>

Get the translation_groups_collection_link value.

pub fn set_translation_groups(&mut self, value: Option<TranslationGroups>)

Set the translation_groups_collection_link value.

pub fn translation_import_queue_entries( &self, ) -> Option<TranslationImportQueueEntries>

Get the translation_import_queue_entries_collection_link value.

pub fn set_translation_import_queue_entries( &mut self, value: Option<TranslationImportQueueEntries>, )

Set the translation_import_queue_entries_collection_link value.