SourcePackagePublishingHistory

Struct SourcePackagePublishingHistory 

pub struct SourcePackagePublishingHistory(/* private fields */);
A source package publishing history record.

Implementations

Source

impl SourcePackagePublishingHistory

pub fn get<'a>( &self, client: &'a dyn Client, ) -> Result<SourcePackagePublishingHistoryFull, Error>

Retrieve the resource.

Returns

Returns SourcePackagePublishingHistoryFull on success, or an error if the request fails.

pub fn get_wadl<'a>(&self, client: &'a dyn Client) -> Result<Resource, Error>

Retrieve the WADL description for this resource.

This method fetches the WADL (Web Application Description Language) specification for the current resource, allowing for runtime API discovery.

Returns

Returns the wadl::ast::Resource definition on success, or an error if the request fails.

pub fn put<'a>( &self, client: &'a dyn Client, representation: &SourcePackagePublishingHistoryFull, ) -> Result<(), Error>

Update the resource.

pub fn patch<'a>( &self, client: &'a dyn Client, representation: &SourcePackagePublishingHistoryDiff, ) -> Result<(), Error>

Partially update the resource.

pub fn get_published_binaries<'a>( &self, client: &'a dyn Client, active_binaries_only: Option<&str>, ) -> Result<PagedCollection<'a, BinaryPackagePublishingHistoryPage>, Error>

Return all resulted IBinaryPackagePublishingHistory.

Follow the build record and return every binary publishing record for any DistroArchSeries in this DistroSeries and in the same IArchive and Pocket, ordered by architecture tag. If active_binaries_only is True (the default), then only return PUBLISHED or PENDING binary publishing records.

Arguments
  • active_binaries_only: Only return active publications
Returns

Returns crate::blocking::page::PagedCollection<'a, BinaryPackagePublishingHistoryPage> on success, or an error if the request fails.

pub fn get_builds<'a>( &self, client: &'a dyn Client, ) -> Result<PagedCollection<'a, BuildPage>, Error>

Return a list of IBuild objects in this publishing context.

The builds are ordered by DistroArchSeries.architecturetag.

Arguments
Returns

Returns crate::blocking::page::PagedCollection<'a, BuildPage> on success, or an error if the request fails.

pub fn changes_file_url<'a>(&self, client: &'a dyn Client) -> Result<(), Error>

The .changes file URL for this source publication.

Arguments
pub fn source_file_urls<'a>( &self, client: &'a dyn Client, include_meta: Option<&bool>, ) -> Result<(), Error>

URLs for this source publication’s uploaded source files.

Arguments
  • include_meta: Include Metadata
pub fn binary_file_urls<'a>(&self, client: &'a dyn Client) -> Result<(), Error>

URLs for this source publication’s binary files.

Arguments
pub fn package_diff_url<'a>( &self, client: &'a dyn Client, to_version: &str, ) -> Result<(), Error>

URL of the debdiff file between this and the supplied version.

Arguments
  • to_version: To Version
pub fn request_deletion<'a>( &self, client: &'a dyn Client, removal_comment: Option<&str>, ) -> Result<(), Error>

Delete this source and its binaries.

Arguments
  • removal_comment: Removal comment