pub struct Specification(/* private fields */);Expand description
A Specification.
Implementations
Sourceimpl Specification
impl Specification
Sourcepub fn get<'a>(
&self,
client: &'a dyn Client,
) -> Result<SpecificationFull, Error>
pub fn get<'a>( &self, client: &'a dyn Client, ) -> Result<SpecificationFull, Error>
Retrieve the resource.
Returns
Returns SpecificationFull on success, or an error if the request fails.
Sourcepub fn get_wadl<'a>(&self, client: &'a dyn Client) -> Result<Resource, Error>
pub fn get_wadl<'a>(&self, client: &'a dyn Client) -> Result<Resource, Error>
Retrieve the WADL description for this resource.
This method fetches the WADL (Web Application Description Language) specification for the current resource, allowing for runtime API discovery.
Returns
Returns the wadl::ast::Resource definition on success, or an error if the request fails.
Sourcepub fn put<'a>(
&self,
client: &'a dyn Client,
representation: &SpecificationFull,
) -> Result<(), Error>
pub fn put<'a>( &self, client: &'a dyn Client, representation: &SpecificationFull, ) -> Result<(), Error>
Update the resource.
Sourcepub fn patch<'a>(
&self,
client: &'a dyn Client,
representation: &SpecificationDiff,
) -> Result<(), Error>
pub fn patch<'a>( &self, client: &'a dyn Client, representation: &SpecificationDiff, ) -> Result<(), Error>
Partially update the resource.