StructuralSubscriptionTarget

Struct StructuralSubscriptionTarget 

pub struct StructuralSubscriptionTarget(/* private fields */);
A Launchpad Structure allowing users to subscribe to it.

Implementations

Source

impl StructuralSubscriptionTarget

pub fn get<'a>( &self, client: &'a dyn Client, ) -> Result<StructuralSubscriptionTargetFull, Error>

Retrieve the resource.

Returns

Returns StructuralSubscriptionTargetFull on success, or an error if the request fails.

pub fn get_wadl<'a>(&self, client: &'a dyn Client) -> Result<Resource, Error>

Retrieve the WADL description for this resource.

This method fetches the WADL (Web Application Description Language) specification for the current resource, allowing for runtime API discovery.

Returns

Returns the wadl::ast::Resource definition on success, or an error if the request fails.

pub fn put<'a>( &self, client: &'a dyn Client, representation: &StructuralSubscriptionTargetFull, ) -> Result<(), Error>

Update the resource.

pub fn patch<'a>( &self, client: &'a dyn Client, representation: &StructuralSubscriptionTargetDiff, ) -> Result<(), Error>

Partially update the resource.

pub fn get_subscriptions<'a>( &self, client: &'a dyn Client, ) -> Result<PagedCollection<'a, StructuralSubscriptionPage>, Error>

Return all the subscriptions with the specified levels.

Arguments
Returns

Returns crate::blocking::page::PagedCollection<'a, StructuralSubscriptionPage> on success, or an error if the request fails.

pub fn get_subscription<'a>( &self, client: &'a dyn Client, person: &Person, ) -> Result<StructuralSubscriptionFull, Error>

Return the subscription for person, if it exists.

Arguments
  • person
Returns

Returns StructuralSubscriptionFull on success, or an error if the request fails.

pub fn user_has_bug_subscriptions<'a>( &self, client: &'a dyn Client, ) -> Result<(), Error>

Is user subscribed, directly or via a team, to bug mail?

Arguments
pub fn add_bug_subscription<'a>( &self, client: &'a dyn Client, subscriber: Option<&Person>, ) -> Result<Option<StructuralSubscription>, Error>

Add a bug subscription for this structure.

This method is used to create a new IStructuralSubscription for the target. This initially has a single filter which will allow all notifications will be sent.

Arguments
  • subscriber: Person to subscribe. If omitted, the requesting user will be subscribed.
Returns

Returns Option<StructuralSubscription> on success, or an error if the request fails.

pub fn add_bug_subscription_filter<'a>( &self, client: &'a dyn Client, subscriber: Option<&Person>, ) -> Result<Option<BugSubscriptionFilter>, Error>

Add a bug subscription filter for this structure.

This method is used to create a new IBugSubscriptionFilter for the target. It will initially allow all notifications to be sent.

Arguments
  • subscriber: Person to subscribe. If omitted, the requesting user will be subscribed.
Returns

Returns Option<BugSubscriptionFilter> on success, or an error if the request fails.

pub fn remove_bug_subscription<'a>( &self, client: &'a dyn Client, subscriber: Option<&Person>, ) -> Result<(), Error>

Remove a subscription to bugs from this structure.

This will delete all associated filters.

Arguments
  • subscriber: Person to unsubscribe. If omitted, the requesting user will be unsubscribed.