pub struct ProjectSeries(/* private fields */);Expand description
A series of releases. For example ‘2.0’ or ‘1.3’ or ‘dev’.
Implementations
Sourceimpl ProjectSeries
impl ProjectSeries
Sourcepub fn get<'a>(
&self,
client: &'a dyn Client,
) -> Result<ProjectSeriesFull, Error>
pub fn get<'a>( &self, client: &'a dyn Client, ) -> Result<ProjectSeriesFull, Error>
Retrieve the resource.
Returns
Returns ProjectSeriesFull on success, or an error if the request fails.
Sourcepub fn get_wadl<'a>(&self, client: &'a dyn Client) -> Result<Resource, Error>
pub fn get_wadl<'a>(&self, client: &'a dyn Client) -> Result<Resource, Error>
Retrieve the WADL description for this resource.
This method fetches the WADL (Web Application Description Language) specification for the current resource, allowing for runtime API discovery.
Returns
Returns the wadl::ast::Resource definition on success, or an error if the request fails.
Sourcepub fn put<'a>(
&self,
client: &'a dyn Client,
representation: &ProjectSeriesFull,
) -> Result<(), Error>
pub fn put<'a>( &self, client: &'a dyn Client, representation: &ProjectSeriesFull, ) -> Result<(), Error>
Update the resource.
Sourcepub fn patch<'a>(
&self,
client: &'a dyn Client,
representation: &ProjectSeriesDiff,
) -> Result<(), Error>
pub fn patch<'a>( &self, client: &'a dyn Client, representation: &ProjectSeriesDiff, ) -> Result<(), Error>
Partially update the resource.
Sourcepub fn search_tasks<'a>(
&self,
client: &'a dyn Client,
order_by: Option<&str>,
search_text: Option<&str>,
status: Option<&str>,
importance: Option<&str>,
information_type: Option<&str>,
assignee: Option<&Person>,
bug_reporter: Option<&Person>,
bug_supervisor: Option<&Person>,
bug_commenter: Option<&Person>,
bug_subscriber: Option<&Person>,
structural_subscriber: Option<&Person>,
owner: Option<&Person>,
affected_user: Option<&Person>,
has_patch: Option<&bool>,
has_cve: Option<&bool>,
tags: Option<&str>,
tags_combinator: Option<&TagsCombinator>,
omit_duplicates: Option<&str>,
status_upstream: Option<&str>,
milestone: Option<&str>,
component: Option<&str>,
nominated_for: Option<&DistroSeries>,
has_no_package: Option<&bool>,
linked_branches: Option<&LinkedBranches>,
modified_since: Option<&DateTime<Utc>>,
created_since: Option<&DateTime<Utc>>,
created_before: Option<&DateTime<Utc>>,
omit_targeted: Option<&str>,
) -> Result<PagedCollection<'a, BugTaskPage>, Error>
pub fn search_tasks<'a>( &self, client: &'a dyn Client, order_by: Option<&str>, search_text: Option<&str>, status: Option<&str>, importance: Option<&str>, information_type: Option<&str>, assignee: Option<&Person>, bug_reporter: Option<&Person>, bug_supervisor: Option<&Person>, bug_commenter: Option<&Person>, bug_subscriber: Option<&Person>, structural_subscriber: Option<&Person>, owner: Option<&Person>, affected_user: Option<&Person>, has_patch: Option<&bool>, has_cve: Option<&bool>, tags: Option<&str>, tags_combinator: Option<&TagsCombinator>, omit_duplicates: Option<&str>, status_upstream: Option<&str>, milestone: Option<&str>, component: Option<&str>, nominated_for: Option<&DistroSeries>, has_no_package: Option<&bool>, linked_branches: Option<&LinkedBranches>, modified_since: Option<&DateTime<Utc>>, created_since: Option<&DateTime<Utc>>, created_before: Option<&DateTime<Utc>>, omit_targeted: Option<&str>, ) -> Result<PagedCollection<'a, BugTaskPage>, Error>
Search the IBugTasks reported on this entity.
Return an iterable of matching results.
Note: milestone is currently ignored for all IBugTargets except IProduct.
Arguments
-
order_by: List of fields by which the results are ordered. -
search_text: Bug ID or search text. -
status: StatusShow only bugs with the given status value or list of values.
-
importance: ImportanceShow only bugs with the given importance or list of importances.
-
information_type: Information TypeShow only bugs with the given information type or list of information types.
-
assignee -
bug_reporter -
bug_supervisor -
bug_commenter -
bug_subscriber -
structural_subscriber -
owner -
affected_user -
has_patch: Show only bugs with patches available. -
has_cve: Show only bugs associated with a CVE -
tags: TagsString or list of strings for tags to search. To exclude, prepend a ‘-’, e.g. ‘-unwantedtag’
-
tags_combinator: Tags combinationSearch for any or all of the tags specified.
-
omit_duplicates: Omit bugs marked as duplicate, -
status_upstream: Status upstreamIndicates the status of any remote watches associated with the bug. Possible values include: pending_bugwatch, hide_upstream, resolved_upstream, and open_upstream.
-
milestone: MilestoneShow only bug tasks targeted to this milestone.
-
component: ComponentDistribution package archive grouping. E.g. main, universe, multiverse
-
nominated_for -
has_no_package: Exclude bugs with packages specified -
linked_branches: Search for bugs that are linked to branches or for bugs that are not linked to branches. -
modified_since: Search for bugs that have been modified since the given date. -
created_since: Search for bugs that have been created since the given date. -
created_before: Search for bugs that were created before the given date. -
omit_targeted: Omit bugs targeted to a series
Returns
Returns crate::blocking::page::PagedCollection<'a, BugTaskPage> on success, or an error if the request fails.
Sourcepub fn get_subscriptions<'a>(
&self,
client: &'a dyn Client,
) -> Result<PagedCollection<'a, StructuralSubscriptionPage>, Error>
pub fn get_subscriptions<'a>( &self, client: &'a dyn Client, ) -> Result<PagedCollection<'a, StructuralSubscriptionPage>, Error>
Sourcepub fn get_subscription<'a>(
&self,
client: &'a dyn Client,
person: &Person,
) -> Result<StructuralSubscriptionFull, Error>
pub fn get_subscription<'a>( &self, client: &'a dyn Client, person: &Person, ) -> Result<StructuralSubscriptionFull, Error>
Sourcepub fn user_has_bug_subscriptions<'a>(
&self,
client: &'a dyn Client,
) -> Result<(), Error>
pub fn user_has_bug_subscriptions<'a>( &self, client: &'a dyn Client, ) -> Result<(), Error>
Is user subscribed, directly or via a team, to bug mail?
Arguments
Sourcepub fn get_translation_import_queue_entries<'a>(
&self,
client: &'a dyn Client,
import_status: Option<&ImportStatus>,
file_extension: Option<&str>,
) -> Result<PagedCollection<'a, TranslationImportQueueEntryPage>, Error>
pub fn get_translation_import_queue_entries<'a>( &self, client: &'a dyn Client, import_status: Option<&ImportStatus>, file_extension: Option<&str>, ) -> Result<PagedCollection<'a, TranslationImportQueueEntryPage>, Error>
Return entries in the translation import queue for this entity.
If one of both of ‘import_status’ or ‘file_extension’ are given, the returned entries are filtered based on those values.
Arguments
-
import_status: StatusShow only entries with this status
-
file_extension: Filename extensionShow only entries with this filename suffix
Returns
Returns crate::blocking::page::PagedCollection<'a, TranslationImportQueueEntryPage> on success, or an error if the request fails.
Sourcepub fn get_translation_templates<'a>(
&self,
client: &'a dyn Client,
) -> Result<PagedCollection<'a, TranslationTemplatePage>, Error>
pub fn get_translation_templates<'a>( &self, client: &'a dyn Client, ) -> Result<PagedCollection<'a, TranslationTemplatePage>, Error>
Sourcepub fn get_timeline<'a>(
&self,
client: &'a dyn Client,
include_inactive: Option<&bool>,
) -> Result<(), Error>
pub fn get_timeline<'a>( &self, client: &'a dyn Client, include_inactive: Option<&bool>, ) -> Result<(), Error>
Return basic timeline data useful for creating a diagram.
The number of milestones returned is limited.
Arguments
include_inactive: Include inactive
Sourcepub fn add_bug_subscription<'a>(
&self,
client: &'a dyn Client,
subscriber: Option<&Person>,
) -> Result<Option<StructuralSubscription>, Error>
pub fn add_bug_subscription<'a>( &self, client: &'a dyn Client, subscriber: Option<&Person>, ) -> Result<Option<StructuralSubscription>, Error>
Add a bug subscription for this structure.
This method is used to create a new IStructuralSubscription for the target. This initially has a single filter which will allow all notifications will be sent.
Arguments
subscriber: Person to subscribe. If omitted, the requesting user will be subscribed.
Returns
Returns Option<StructuralSubscription> on success, or an error if the request fails.
Sourcepub fn add_bug_subscription_filter<'a>(
&self,
client: &'a dyn Client,
subscriber: Option<&Person>,
) -> Result<Option<BugSubscriptionFilter>, Error>
pub fn add_bug_subscription_filter<'a>( &self, client: &'a dyn Client, subscriber: Option<&Person>, ) -> Result<Option<BugSubscriptionFilter>, Error>
Add a bug subscription filter for this structure.
This method is used to create a new IBugSubscriptionFilter for the target. It will initially allow all notifications to be sent.
Arguments
subscriber: Person to subscribe. If omitted, the requesting user will be subscribed.
Returns
Returns Option<BugSubscriptionFilter> on success, or an error if the request fails.
Sourcepub fn remove_bug_subscription<'a>(
&self,
client: &'a dyn Client,
subscriber: Option<&Person>,
) -> Result<(), Error>
pub fn remove_bug_subscription<'a>( &self, client: &'a dyn Client, subscriber: Option<&Person>, ) -> Result<(), Error>
Remove a subscription to bugs from this structure.
This will delete all associated filters.
Arguments
subscriber: Person to unsubscribe. If omitted, the requesting user will be unsubscribed.
Sourcepub fn new_milestone<'a>(
&self,
client: &'a dyn Client,
name: &str,
date_targeted: Option<&NaiveDate>,
summary: Option<&str>,
code_name: Option<&str>,
) -> Result<Option<Milestone>, Error>
pub fn new_milestone<'a>( &self, client: &'a dyn Client, name: &str, date_targeted: Option<&NaiveDate>, summary: Option<&str>, code_name: Option<&str>, ) -> Result<Option<Milestone>, Error>
Create a new milestone for this ProjectSeries.
Arguments
-
name: NameOnly letters, numbers, and simple punctuation are allowed.
-
date_targeted: Date TargetedExample: 2005-11-24
-
summary: SummaryA summary of the features and status of this milestone.
-
code_name: Code nameAn alternative name for the milestone.
Returns
Returns Option<Milestone> on success, or an error if the request fails.